@@ -8,12 +8,16 @@ export interface ITransformerStates {
     isPostprocessorTagged?: boolean;
     isRequirementsTagged?: boolean;
     isCVATInfoTagged?: boolean;
+    isCVATPreprocessorTagged?: boolean;
+    isCVATPostprocessorTagged?: boolean;
 }
 const transformerStates: ITransformerStates = {
     isPreprocessorTagged: false,
     isPostprocessorTagged: false,
     isRequirementsTagged: false,
-    isCVATInfoTagged: false
+    isCVATInfoTagged: false,
+    isCVATPreprocessorTagged: false,
+    isCVATPostprocessorTagged: false
 }
 let stateChangeListeners: ((trigger: string, newStates: ITransformerStates) => void)[] = [];
 
