@@ -4,13 +4,15 @@ import CheckIcon from '@material-ui/icons/Check';
 import { IconButton } from '@material-ui/core';
 import { Select } from './../components/Select';
 import TagsUtils from './../lib/TagsUtils';
-import { Notebook, NotebookPanel/*, NotebookActions*/ } from '@jupyterlab/notebook';
+import { Notebook, NotebookPanel, NotebookActions } from '@jupyterlab/notebook';
 import { Chip, Tooltip } from '@material-ui/core';
 import { CellMetadataEditorDialog } from './CellMetadataEditorDialog';
 import { ISettingRegistry } from '@jupyterlab/settingregistry';
 import { getTransformerEnabled } from './../settings';
 import { fetchTransformerStattes, issueTransformerStatesChange, addStatesChangeListener, ITransformerStates } from './../states'
+import { showCurrentActiveCellTransformerWidget } from './../notebook'
 import CellUtils from './../lib/CellUtils';
+import * as nbformat from '@jupyterlab/nbformat';
 
 const CELL_TYPE_NA = 'na';
 const CELL_TYPE_NA_LABEL = '-';
@@ -271,8 +273,10 @@ export class CellMetadataEditor extends React.Component<IProps, IState> {
                 this.setState({ transformerTag: CELL_TYPE_NA });
             }
 
+            let notebook: Notebook = this.props.notebookPanel.content;
+            let currentCellType: string = this.props.notebookPanel.model.cells.get(notebook.activeCellIndex).type;
+            let targetCellType: string = currentCellType;
             if(value == CELL_TYPE_PREPROCESSOR || value == CELL_TYPE_POSTPROCESSOR || value == CELL_TYPE_CVAT_INFO || value == CELL_TYPE_CVAT_PREPROCESSOR || value == CELL_TYPE_CVAT_POSTPROCESSOR) {
-                let notebook: Notebook = this.props.notebookPanel.content;
                 let confirmedResult = this.checkCellCodeDefinitionConfirmed(notebook, notebook.activeCellIndex, value);
                 if(! confirmedResult.confirmed) {
                     let codeSnippet = PREPROCESSOR_DEFAULT_CODE_SNIPPET;
@@ -298,13 +302,25 @@ export class CellMetadataEditor extends React.Component<IProps, IState> {
                         this.toggleTagsEditorDialog();
                     }
                 }
-                //NotebookActions.changeCellType(this.props.notebookPanel.content, 'code');
+                targetCellType = 'code';
             } else if(value == CELL_TYPE_REQUIREMENTS) {
-                /*
-                await this.props.notebookPanel.context.save();
-                NotebookActions.changeCellType(this.props.notebookPanel.content, 'raw');
-                this.props.notebookPanel.activate();
-                */
+                targetCellType = 'raw';
+            }
+
+            if(currentCellType != targetCellType) {
+                console.log("Keep transformer metadata in cell metadata and replace cell widget...");
+                let cellMetadata = {
+                    transformerTag: value,
+                };
+                TagsUtils.setCellTransformerTag(
+                    this.props.notebookPanel,
+                    notebook.activeCellIndex,
+                    cellMetadata,
+                    false
+                ).then(newValue => {
+                    NotebookActions.changeCellType(notebook, targetCellType as nbformat.CellType);
+                    showCurrentActiveCellTransformerWidget(this.props.notebookPanel);
+                });
             }
         }
     };
