@@ -4,11 +4,29 @@ import { theme } from './../theme';
 import { executeRpc, globalUnhandledRejection } from './../lib/RPCUtils';
 import NotebookUtils from './../lib/NotebookUtils';
 import { Kernel } from '@jupyterlab/services';
-import { Switch } from '@material-ui/core';
 import { ISettingRegistry } from '@jupyterlab/settingregistry';
-import { getTransformerEnabled, setTransformerEnabled, getTransformerProxyUrl } from './../settings';
-import { getTransformerNotebookDirectory, saveTransformerNotebook } from './../notebook';
-import { Button, Dialog, DialogActions, DialogContent, DialogTitle } from '@material-ui/core';
+import { getTransformerEnabled, setTransformerEnabled, getTransformerProxyUrl, addStatusChangeListener, StatusContent, triggerStatusUpdate, setTransformerNotebookPath } from './../settings';
+import { saveTransformerNotebook } from './../notebook';
+import {
+    Switch,
+    Divider,
+    Typography,
+    Button,
+    Dialog,
+    DialogActions,
+    DialogContent,
+    DialogTitle,
+    Collapse,
+    Accordion,
+    AccordionSummary,
+    AccordionDetails,
+    CircularProgress,
+    Select,
+    MenuItem
+} from '@material-ui/core';
+import InfoIcon from '@material-ui/icons/Info';
+import ExpandMoreIcon from '@material-ui/icons/ExpandMoreRounded';
+import RefreshIcon from '@material-ui/icons/Refresh';
 
 interface IProps {
     transformerSettings: ISettingRegistry.ISettings
@@ -24,6 +42,13 @@ interface IState {
     closeButtonText: string;
     isDialogConfirmButtonVisible: boolean;
     dialogConfirmClickHandler: ClickHandler;
+    showApplyTransformerDescription: boolean;
+    showResetTransformerDescription: boolean;
+    proxyUrl: string;
+    proxyStatus: string;
+    transformerNotebookPath: string;
+    transformerNotebookPathOptions: string[];
+    isStatusLoading: boolean;
 }
 
 interface IDialogParams {
@@ -42,6 +67,8 @@ export class TransformerLeftPanel extends React.Component<IProps, IState> {
         this.onDialogConfirmClick = this.onDialogConfirmClick.bind(this);
         this.doResetTransformer = this.doResetTransformer.bind(this);
         this.doReloadPage = this.doReloadPage.bind(this);
+        this.refreshStatus = this.refreshStatus.bind(this);
+        this.changetransformerNotebookPath = this.changetransformerNotebookPath.bind(this);
         const defaultState: IState = {
             isEnabled: getTransformerEnabled(),
             isDialogVisible: false,
@@ -50,7 +77,14 @@ export class TransformerLeftPanel extends React.Component<IProps, IState> {
             dialogContent: '',
             closeButtonText: 'Ok',
             isDialogConfirmButtonVisible: false,
-            dialogConfirmClickHandler: this.onDialogConfirmClick
+            dialogConfirmClickHandler: this.onDialogConfirmClick,
+            showApplyTransformerDescription: false,
+            showResetTransformerDescription: false,
+            proxyUrl: '',
+            proxyStatus: 'Unavailable',
+            transformerNotebookPath: '',
+            transformerNotebookPathOptions: [],
+            isStatusLoading: true
         };
         this.state = defaultState;
     }
@@ -73,6 +107,20 @@ export class TransformerLeftPanel extends React.Component<IProps, IState> {
         });
     }
 
+    changetransformerNotebookPath(value: string) {
+        this.setState({
+            transformerNotebookPath: value
+        });
+        setTransformerNotebookPath(this.props.transformerSettings, value);
+    }
+
+    refreshStatus() {
+        this.setState({
+            isStatusLoading: true
+        });
+        triggerStatusUpdate(this.props.transformerSettings);
+    }
+
     onDialogCloseClick() {
         this.renderDialog({
             visible: !this.state.isDialogVisible
@@ -87,6 +135,15 @@ export class TransformerLeftPanel extends React.Component<IProps, IState> {
     }
 
     componentDidMount = () => {
+        addStatusChangeListener((status: StatusContent) => {
+            this.setState({
+                proxyUrl: status.proxy_url,
+                proxyStatus: status.proxy_status,
+                transformerNotebookPath: status.notebook_path,
+                transformerNotebookPathOptions: status.nb_path_options,
+                isStatusLoading: false
+            });
+        });
     };
 
     componentDidUpdate = (
@@ -129,7 +186,7 @@ export class TransformerLeftPanel extends React.Component<IProps, IState> {
             const kernel: Kernel.IKernelConnection = await NotebookUtils.createNewKernel();
             const args = {
                 proxy_url: proxyUrl,
-                source_notebook_path: getTransformerNotebookDirectory()
+                source_notebook_path: this.state.transformerNotebookPath
             }
             await executeRpc(kernel, 'proxy.apply', args);
             kernel.shutdown();
@@ -179,7 +236,7 @@ export class TransformerLeftPanel extends React.Component<IProps, IState> {
             const kernel: Kernel.IKernelConnection = await NotebookUtils.createNewKernel();
             const args = {
                 proxy_url: proxyUrl,
-                source_notebook_path: getTransformerNotebookDirectory()
+                source_notebook_path: this.state.transformerNotebookPath
             }
             await executeRpc(kernel, 'proxy.reset', args);
             kernel.shutdown();
@@ -218,16 +275,12 @@ export class TransformerLeftPanel extends React.Component<IProps, IState> {
             <ThemeProvider theme={theme}>
                 <div className={'leftpanel-transformer-widget'} key="transformer-widget" style={{padding: 'var(--jp-code-padding)'}}>
                     <div className={'leftpanel-transformer-widget-content'}>
-                        <div className="transformer-header" style={{fontSize: 'var(--jp-ui-font-size3)'}} >
-                            <p>Transformer Panel</p>
-                        </div>
+                        <Typography variant="h5" gutterBottom>Transformer Panel</Typography>
 
                         <div className='transformer-component' >
-                            <div>
-                                <p className="transformer-header" style={{ color: theme.transformer.headers.main, fontSize: 'var(--jp-ui-font-size1)'}}>
-                                    Transformer is the extension for model inference, it injects pre and post processors defined in <strong style={{fontSize: 'var(--jp-ui-font-size2)'}}>transformer.ipynb</strong> notebook.
-                                </p>
-                            </div>
+                            <Typography variant="body1" gutterBottom style={{ color: theme.transformer.headers.main }}>
+                                Transformer is the extension for model inference, it injects pre and post processors defined in <strong style={{ fontWeight: '600' }}>transformer.ipynb</strong> notebook.
+                            </Typography>
                         </div>
 
                         <div className="transformer-toggler">
@@ -242,18 +295,93 @@ export class TransformerLeftPanel extends React.Component<IProps, IState> {
                                         classes={{ root: 'material-switch' }}
                                     />
                                     <div className={'switch-label'} style={{ display: 'inline-block' }}>
-                                        {(this.state.isEnabled ? 'Disable' : 'Enable') + ' transformer widgets'}
+                                        <Typography variant="overline" display="block">{(this.state.isEnabled ? 'Disable' : 'Enable') + ' widgets'}</Typography>
                                     </div>
                                 </div>
                             </React.Fragment>
                         </div>
-
                         <div className={ 'transformer-component' + (this.state.isEnabled ? '' : ' hidden') } style={{ marginTop: '1em' }}>
-                            <div>
-                                <p className="transformer-header" style={{ color: theme.transformer.headers.main, fontSize: 'var(--jp-ui-font-size1)'}}>
-                                    Convert <strong style={{fontSize: 'var(--jp-ui-font-size2)'}}>transformer.ipynb</strong> to runnable python code and apply the pre and post processors for model inference.
-                                </p>
-                            </div>
+                            <Divider variant="middle" style={{ margin: '1em 0' }} />
+                            <Typography variant="subtitle2" display="block" gutterBottom>
+                                STATUS
+                                <span>
+                                    {this.state.isStatusLoading && <CircularProgress size={16} style={{ position: "relative", top: "0.2em", left: "0.5em"}}/>}
+                                    {!this.state.isStatusLoading && <RefreshIcon onClick={this.refreshStatus} color="primary" fontSize="small" style={{ position: "relative", top: "0.25em", left: "0.2em", cursor: "pointer" }}/>}
+                                </span>
+                            </Typography>
+                            <Accordion style={{ margin: '0 0.2em' }}>
+                                <AccordionSummary
+                                    expandIcon={<ExpandMoreIcon />}
+                                    aria-controls="panel1a-content"
+                                >
+                                    <Typography variant="subtitle2"
+                                        style={{ color: this.state.proxyUrl? 'green': 'red' }}
+                                    >Proxy URL: {this.state.proxyUrl? 'Set': 'Empty'}</Typography>
+                                </AccordionSummary>
+                                <AccordionDetails>
+                                    <Typography variant="body2" gutterBottom>
+                                        {this.state.proxyUrl? 'Proxy URL is now: ' + this.state.proxyUrl: 'Unable to retrieve proxy URL from system settings.'}
+                                    </Typography>
+                                </AccordionDetails>
+                            </Accordion>
+                            <Accordion style={{ margin: '0 0.2em' }}>
+                                <AccordionSummary
+                                    expandIcon={<ExpandMoreIcon />}
+                                    aria-controls="panel1a-content"
+                                >
+                                    <Typography variant="subtitle2"
+                                        style={{ color: this.state.proxyStatus === 'healthy'? 'green': 'red' }}
+                                    >Proxy status: {this.state.proxyStatus === 'healthy'? 'Available': 'Unavailable'}</Typography>
+                                </AccordionSummary>
+                                <AccordionDetails>
+                                    <Typography variant="body2" gutterBottom>
+                                        {this.state.proxyStatus === 'healthy'? 'Ready to apply transformer to proxy.': 'Lose connection to proxy server!'}
+                                    </Typography>
+                                </AccordionDetails>
+                            </Accordion>
+                            <Accordion style={{ margin: '0 0.2em' }}>
+                                <AccordionSummary
+                                    expandIcon={<ExpandMoreIcon />}
+                                    aria-controls="panel1a-content"
+                                >
+                                    <Typography variant="subtitle2"
+                                        style={{ color: this.state.transformerNotebookPath? 'green': 'red' }}
+                                    >Transformer NB: {this.state.transformerNotebookPath? 'Set': 'Unknown'}</Typography>
+                                </AccordionSummary>
+                                <AccordionDetails>
+                                    <div>
+                                        <Select
+                                            value={this.state.transformerNotebookPath}
+                                            onChange={e => this.changetransformerNotebookPath(e.target.value as string)}
+                                        >
+                                        {this.state.transformerNotebookPathOptions.map((value) => (
+                                            <MenuItem key={value} value={value}>{value}</MenuItem>
+                                        ))}
+                                        </Select>
+                                        <Typography variant="body2" display="block" gutterBottom>
+                                            {this.state.transformerNotebookPath? 'Notebook(' + this.state.transformerNotebookPath + ') will be applied.': 'Notebook transformer.ipynb is not found!'}
+                                        </Typography>
+                                    </div>
+                                </AccordionDetails>
+                            </Accordion>
+                        </div>
+                        <div className={ 'transformer-component' + (this.state.isEnabled ? '' : ' hidden') } style={{ marginTop: '1em' }}>
+                            <Divider variant="middle" style={{ margin: '1em 0' }} />
+                            <Typography variant="subtitle2" display="block" gutterBottom>
+                                APPLY TRANSFORMER
+                                <InfoIcon
+                                    onClick={() => this.setState({
+                                        showApplyTransformerDescription: !this.state.showApplyTransformerDescription
+                                    }) }
+                                    aria-label="show more"
+                                    style={{ position: "relative", top: "0.25em", margin: "0 0.2em", cursor: "pointer" }}
+                                />
+                            </Typography>
+                            <Collapse in={this.state.showApplyTransformerDescription} timeout="auto" unmountOnExit>
+                                <Typography variant="body1" gutterBottom style={{ color: theme.transformer.headers.main }}>
+                                    Convert <strong style={{ fontWeight: '600' }}>transformer.ipynb</strong> to runnable python code and apply the pre and post processors for model inference.
+                                </Typography>
+                            </Collapse>
                             <div className="input-container add-button">
                                 <Button
                                     variant="contained"
@@ -262,19 +390,26 @@ export class TransformerLeftPanel extends React.Component<IProps, IState> {
                                     title="Apply the changes."
                                     onClick={this.applyTransformerToProxy}
                                     disabled={ false }
-                                    style={{ marginLeft: '10px', marginTop: '0px' }}
-                                >
-                                    Apply Transformer
-                                </Button>
+                                >Now Apply</Button>
                             </div>
                         </div>
-
                         <div className={ 'transformer-component' + (this.state.isEnabled ? '' : ' hidden') } style={{ marginTop: '1em' }}>
-                            <div>
-                                <p className="transformer-header" style={{ color: theme.transformer.headers.main, fontSize: 'var(--jp-ui-font-size1)'}}>
-                                    Reset <strong style={{fontSize: 'var(--jp-ui-font-size2)'}}>transformer.ipynb</strong>, this action also reset the pre and post processors for model inference.
-                                </p>
-                            </div>
+                            <Divider variant="middle" style={{ margin: '1em 0' }} />
+                            <Typography variant="subtitle2" display="block" gutterBottom>
+                                RESET TRANSFORMER
+                                <InfoIcon
+                                    onClick={() => this.setState({
+                                        showResetTransformerDescription: !this.state.showResetTransformerDescription
+                                    }) }
+                                    aria-label="show more"
+                                    style={{ position: "relative", top: "0.25em", margin: "0 0.2em", cursor: "pointer" }}
+                                />
+                            </Typography>
+                            <Collapse in={this.state.showResetTransformerDescription} timeout="auto" unmountOnExit>
+                                <Typography variant="body1" gutterBottom style={{ color: theme.transformer.headers.main }}>
+                                    Reset <strong style={{ fontWeight: '600' }}>transformer.ipynb</strong>, this action also reset the pre and post processors for model inference.
+                                </Typography>
+                            </Collapse>
                             <div className="input-container add-button">
                                 <Button
                                     variant="contained"
@@ -283,10 +418,7 @@ export class TransformerLeftPanel extends React.Component<IProps, IState> {
                                     title="Reset Transformer"
                                     onClick={this.resetTransformer}
                                     disabled={ false }
-                                    style={{ marginLeft: '10px', marginTop: '0px' }}
-                                >
-                                    Reset Transformer
-                                </Button>
+                                >Now Reset</Button>
                             </div>
                         </div>
                     </div>
